@@ -1,7 +1,17 @@
 import fire
 import toml
+import os
+import shutil
+from ..env import pkg_data_path
+
+export_data_path=os.path.join(pkg_data_path,'mdblog')
 
 class Cli:
+    @classmethod
+    def export(self, path='./'):
+        if os.path.exists(path):
+            path = os.path.join(path, 'mdblog')
+        shutil.copytree(export_data_path, path)
     @staticmethod
     def run(config=None):
         from mdblog.config import CONFIG
